## Main Tasks
- [x] main branch - proper pypi integration
- [ ] presentation
- [ ] syphinx documentation


- [ ] friday funboard
- [ ] short 
- [ ] ask people what can be used for at the end of the presentation

### Sub Tasks
- [x] better `--list` option output
 




- lets talk about aws api
    - it's an http api 
    - sheer size 